/*
===========================================================
  
  Schedule

===========================================================
*/

/*
-----------------------------------------------------------
  Import
-----------------------------------------------------------
*/

// NPM
import { 
  lightFormat, 
  parseISO, 
  getISODay, 
} from 'date-fns'


import { get } from '~creek-website-toolkit/lib/utils'


/*
-----------------------------------------------------------
  Exported Functions
-----------------------------------------------------------
*/

const getISOWeekdays = () => {

  return [
    'Sunday',
    'Monday',
    'Tuesday',
    'Wednesday',
    'Thursday',
    'Friday',
    'Saturday',
    'Sunday',
  ]

}

const getISOWeekday = (ISOWeekdayNum) => {
  return getISOWeekdays()[ISOWeekdayNum]
}

const getISOWeekdayFromDate = (date) => {
  return getISOWeekday(
    getISODay(date)
  )
}

const getISOWeekdayNumberFromDate = (date) => {
  // X('woof')
  // X(parseISO(date))
  return getISODay(date)
}

const getISOWeekdayNumberForToday = () => {
  return getISODay(new Date())
}

const getTimespanString = (start, end) => {

  let val = null
  
  if(start && end){

    const startParsed = parseISO(start)
    const endParsed = parseISO(end)

    val = lightFormat(startParsed, 'h:mma') 
      + ` - `
      + lightFormat(endParsed, 'h:mma')

  }

  return val

}

const getTimespanStringFromActiveSource = (globalPlayerState, studioState) => {

  let start = null
  let end = null
  let val = null

  if(globalPlayerState.hasBroadcast){

    // Try using timespan from Broadcast object first.
    start = get(globalPlayerState, `sources.broadcast.start`)
    end = get(globalPlayerState, `sources.broadcast.end`)

  }else{

    // Fall back to current for live stream.
    // TOOD: This should only be for studios that have live streams.
    start = get(studioState, `current.time.start`)
    end = get(studioState, `current.time.end`)

  }

  val = getTimespanString(start, end)

  return val

}

const getTimeString = (time) => {

  let val = null

  const startParsed = parseISO(time.start)
  const endParsed = parseISO(time.end)

  val = getISOWeekday(getISODay(startParsed))
    + ` `
    + lightFormat(startParsed, 'h:mma') 
    + ` - `
    + lightFormat(endParsed, 'h:mma')

  return val

}

/*
-----------------------------------------------------------
  Export
-----------------------------------------------------------
*/

export default {
  getISOWeekdays,
  getISOWeekday,
  getISOWeekdayFromDate,
  getISOWeekdayNumberFromDate,
  getISOWeekdayNumberForToday,
  getTimespanString,
  getTimespanStringFromActiveSource,
  getTimeString,
}

