
import { 
  sub, 
  lightFormat, 
  // format as formatDate, 
  getISODay,
  parseISO 
} from 'date-fns'

import { get } from '~creek-website-toolkit/lib/utils'

const getISOWeekdays = () => {

  return [
    'Sunday',
    'Monday',
    'Tuesday',
    'Wednesday',
    'Thursday',
    'Friday',
    'Saturday',
    'Sunday',
  ]

}

const getISOWeekday = (ISOWeekdayNum) => {
  return getISOWeekdays()[ISOWeekdayNum]
}

const getISOWeekdayFromDate = (date) => {
  return getISOWeekday(
    getISODay(date)
  )
}

const getISOWeekdayNumberFromDate = (date) => {
  // X('woof')
  // X(parseISO(date))
  return getISODay(date)
}

const getISOWeekdayNumberForToday = () => {
  return getISODay(new Date())
}

const getTimespanString = (start, end) => {

  let val = null
  
  if(start && end){

    const startParsed = parseISO(start)
    const endParsed = parseISO(end)

    val = lightFormat(startParsed, 'h:mma') 
      + ` - `
      + lightFormat(endParsed, 'h:mma')

  }

  return val

}

const getTimespanString2 = (start, end) => {

  const startDateJS = new Date(start)
  const endDateJS = new Date(end)

  let startTime = lightFormat(startDateJS, 'h:mma')
  let startDate = lightFormat(startDateJS, 'M/d/y')
  let endTime = lightFormat(endDateJS, 'h:mma')
  let endDate = lightFormat(endDateJS, 'M/d/y')
  
  // X(getMinutes(startDateJS))

  // if(getMinutes(startDateJS) == 0){
  //   startTime = lightFormat(
  //     startDateJS, 'haaaaa'
  //   )
  // }
  // if(getMinutes(endDateJS) == 0){
  //   endTime = lightFormat(
  //     endDateJS, 'haaaaa'
  //   )
  // }

  // Only display start date if it's different than end date.
  let startDateIfNeeded = ''
  if(startDate != endDate){
    startDateIfNeeded = ' ' + startDate
  }

  const date = startTime + startDateIfNeeded 
    + ' &rarr; ' + endTime + ' ' + endDate

  return date

}

const getTimespanStringFromActiveSource = (globalPlayerState, studioState) => {

  let start = null
  let end = null
  let val = null

  if(globalPlayerState.hasBroadcast){

    // Try using timespan from Broadcast object first.
    start = get(globalPlayerState, `sources.broadcast.start`)
    end = get(globalPlayerState, `sources.broadcast.end`)

  }else{

    // Fall back to current for live stream.
    // TOOD: This should only be for studios that have live streams.
    start = get(studioState, `current.time.start`)
    end = get(studioState, `current.time.end`)

  }

  val = getTimespanString(start, end)

  return val

}

const getTimeString = (time, separator = null) => {

  let val = null

  if(!separator){
    separator = `–`
  }

  const startParsed = parseISO(time.start)
  const endParsed = parseISO(time.end)

  val = getISOWeekday(getISODay(startParsed))
    + ` `
    + lightFormat(startParsed, 'h:mma') 
    + separator
    + lightFormat(endParsed, 'h:mma')

  return val

}

const format = (date) => {
  
  // X(date)
  
  if(!date){
    return ''
  }

  let parsed = null
  let formatted = null

  try{

    // X(typeof date)
    // X(date instanceof Date)

    if(!(date instanceof Date)){
      // X('not a date!')
      parsed = parseISO(date)
    }else{
      // X('is a date')
      parsed = date
    }

  }catch(error){
    X(error)
  } 

  try{

    // // HACK: Subtract 5 weeks.
    // const parsedHack1 = sub(parsed, { years: 1 })

    // X(parsedHack1)

    // formatted = formatDate(parsed, 'K:mmaa')
    formatted = lightFormat(parsed, 'h:mma')

  }catch(error){
    X('Could not parse date:')
    X(error)
  } 

  return formatted
}


const formatDate = (date) => {
  
  // X(date)
  
  if(!date){
    return ''
  }

  let parsed = null
  let formatted = null

  try{

    // X(typeof date)
    // X(date instanceof Date)

    if(!(date instanceof Date)){
      // X('not a date!')
      parsed = parseISO(date)
    }else{
      // X('is a date')
      parsed = date
    }

  }catch(error){
    X(error)
  } 

  try{

    // // HACK: Subtract 5 weeks.
    // const parsedHack1 = sub(parsed, { years: 1 })

    // X(parsedHack1)

    // formatted = formatDate(parsed, 'K:mmaa')
    formatted = lightFormat(parsed, 'M/d/yyyy')

  }catch(error){
    X('Could not parse date:')
    X(error)
  } 

  return formatted
}


const formatDateAndTime = (date) => {
  
  console.log('parsing date: ' + date)
  
  if(!date){
    return ''
  }

  let parsed = null
  let formatted = null

  try{

    // X(typeof date)
    // X(date instanceof Date)

    if(!(date instanceof Date)){
      // X('not a date!')
      parsed = parseISO(date)
    }else{
      // X('is a date')
      parsed = date
    }

  }catch(error){
    console.log(error)
  } 

  try{

    // // HACK: Subtract 5 weeks.
    // const parsedHack1 = sub(parsed, { years: 1 })

    // X(parsedHack1)

    formatted = lightFormat(parsed, 'h:mmaa M/d/yyyy')
    // formatted = lightFormat(parsed, 'M/d/yyyy')

  }catch(error){
    console.log('Could not parse date:')
    console.log(error)
  } 

  return formatted
}

export default {

  format,
  formatDate,
  formatDateAndTime,

  getISOWeekdays,
  getISOWeekday,
  getISOWeekdayFromDate,
  getISOWeekdayNumberFromDate,
  getISOWeekdayNumberForToday,
  getTimespanString,
  getTimespanString2,
  getTimespanStringFromActiveSource,
  getTimeString,

}
