/*
===========================================================
  
Vanilla JS replacements for Lodash methods

=========================================================== */

/*
-----------------------------------------------------------
  Get
----------------------------------------------------------- */
const get = (obj, path, defaultValue) => {
    const travel = regexp =>
      String.prototype.split
        .call(path, regexp)
        .filter(Boolean)
        .reduce((res, key) => (res !== null && res !== undefined ? res[key] : res), obj);
    const result = travel(/[,[\]]+?/) || travel(/[,[\].]+?/);
    return result === undefined || result === obj ? defaultValue : result;
};

/*
-----------------------------------------------------------
  Clone
----------------------------------------------------------- */
const clone = (obj) => JSON.parse(JSON.stringify(obj))


/*
-----------------------------------------------------------
  Capitalize
----------------------------------------------------------- */
const capitalize = (name) => name.toLowerCase().charAt(0).toUpperCase() + name.slice(1)


/*
-----------------------------------------------------------
  OrderBy
----------------------------------------------------------- */
const orderBy = (arr, keyName, type ) => {
    return arr.sort((a, b) => {
        if (type !== 'asc' && type !== 'desc') return

        if (type === 'asc') return a[keyName].localeCompare(b[keyName])
        else return b[keyName].localeCompare(a[keyName])
    });
}


export {
    get,
    clone,
    capitalize,
    orderBy
}